summaryrefslogtreecommitdiffstats
path: root/generator.h
diff options
context:
space:
mode:
Diffstat (limited to 'generator.h')
-rw-r--r--generator.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/generator.h b/generator.h
index d748397..4c20268 100644
--- a/generator.h
+++ b/generator.h
@@ -151,7 +151,10 @@ public:
/// Returns the generator's name. Used for cosmetic purposes.
virtual const char* name() const = 0;
- /// Returns true if the generator should generate any code for the AbstractMetaClass
+ /// Returns true if the generator should generate any code for the TypeEntry.
+ bool shouldGenerateTypeEntry(const TypeEntry*) const;
+
+ /// Returns true if the generator should generate any code for the AbstractMetaClass.
virtual bool shouldGenerate(const AbstractMetaClass *) const;
/// Returns the subdirectory used to write the binding code of an AbstractMetaClass.